@@ -17,7 +17,7 @@ BEGIN {
   use Exporter   ();
   use AutoLoader qw(AUTOLOAD);
   use vars       qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
-  $VERSION =	 do { my @r=(q$Revision: 1.24 $=~/\d+/g); sprintf "%d."."%02d"x$#r,@r };
+  $VERSION =	 do { my @r=(q$Revision: 1.29 $=~/\d+/g); sprintf "%d."."%02d"x$#r,@r };
   @ISA =         qw();
   @EXPORT =      qw();
   @EXPORT_OK =   qw();
@@ -77,7 +77,9 @@ my %classTypes = (
   20 => "FlashBackup",
   21 => "SplitMirror",
   22 => "AFS",
+  29 => "VCB",
   30 => "Vault",
+  35 => "NBU-Catalog",
 );
 
 my $rollCalled = 0;
@@ -215,6 +217,28 @@ sub list {
   return (values %classRoom);
 }
 
+sub create {
+  my $proto = shift;
+
+}
+
+sub clone {
+  my $self = shift;
+
+}
+
+sub update {
+  my $self = shift;
+
+  return $self;
+}
+
+sub delete {
+  my $self = shift;
+
+  return $self;
+}
+
 sub loadClient {
   my $self = shift;
   my $newClient = shift;
@@ -272,10 +296,11 @@ sub schedules {
 }
 
 sub policies {
-  my $self = shift;
+  my $proto = shift;
+  my $self = ref($proto) ? $proto : undef;;
 
-  $self->populate if (!$self->{LOADED});
-  my $policiesR = $self->{POLICIES};
+  $proto->populate if (!$self->{LOADED});
+  my $policiesR = $proto->{POLICIES};
   return (defined($policiesR) ? (@$policiesR) : ());
 }
 
@@ -567,3 +592,48 @@ sub images {
 1;
 
 __END__
+
+=head1 NAME
+
+NBU::Class - Support for NBU Policies (formerly known as Classes)
+
+=head1 SUPPORTED PLATFORMS
+
+=over 4
+
+=item * 
+
+Solaris
+
+=item * 
+
+Windows/NT
+
+=back
+
+=head1 SYNOPSIS
+
+    To come...
+
+=head1 DESCRIPTION
+
+This module provides support for ...
+
+=head1 SEE ALSO
+
+=over 4
+
+=item L<NBU::Media|NBU::Media>
+
+=back
+
+=head1 AUTHOR
+
+Winkeler, Paul pwinkeler@pbnj-solutions.com
+
+=head1 COPYRIGHT
+
+Copyright (C) 2002-2007 Paul Winkeler
+
+=cut
+
