@@ -12,7 +12,7 @@ BEGIN {
   use Exporter   ();
   use AutoLoader qw(AUTOLOAD);
   use vars       qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
-  $VERSION =	 do { my @r=(q$Revision: 1.22 $=~/\d+/g); sprintf "%d."."%02d"x$#r,@r };
+  $VERSION =	 do { my @r=(q$Revision: 1.24 $=~/\d+/g); sprintf "%d."."%02d"x$#r,@r };
   @ISA =         qw();
   @EXPORT =      qw();
   @EXPORT_OK =   qw();
@@ -89,6 +89,8 @@ sub populate {
   my $proto = shift;
   my $server = shift;
 
+  return if (!$server->roboticMediaManager());
+
   if (!exists($driveHosts{$server->name})) {
     my $driveCount = 0;
     my $pipe = NBU->cmd("vmoprcmd -h ".$server->name." -xdraw ds |");
@@ -112,6 +114,16 @@ sub populate {
       $drive->{CONTROL} = $control;
       $drive->{STATUS} = ($control !~ /DOWN/) ? "UP" : "DOWN";
 
+      $drive->{INUSE} = ($state & 0x000f);
+
+      #
+      # If the drive is busy, and the media has no recorded ID yet, but it
+      # does have an external ID, then this media is being used for the first
+      # time and it will have its external ID recorded henceforth.  So here we
+      # simply jump the gun a little...
+      if ($drive->busy && ($rvsn eq "-") && ($evsn ne "-")) {
+        $rvsn = $evsn;
+      }
       if ($rvsn ne "-") {
 	# Unfortunately there is no way to find out which job is using this drive :-(
 	if (defined(my $volume = NBU::Media->new($rvsn))) {
@@ -182,6 +194,10 @@ sub updateStatus {
   my $proto = shift;
   my $server = shift;
 
+  #
+  # Only applies to robotic media managers
+  return if (!$server->roboticMediaManager());
+
   my $pipe = NBU->cmd("vmoprcmd -h ".$server->name." -xdraw ds |");
   while (<$pipe>) {
     next unless (/^DRIVESTATUS/);
@@ -195,10 +211,15 @@ sub updateStatus {
     $drive->comment($comment);
     $drive->{LASTCLEANED} = $lastCleaned;
 
+    $drive->{INUSE} = ($state & 0x000f);
+
     $drive->status($control);
 
     if ($drive->busy) {
       my $mount = $drive->mount;
+      if (($rvsn eq "-") && ($evsn ne "-")) {
+        $rvsn = $evsn;
+      }
 
       if ($rvsn eq "-") {
         $drive->free(time);
@@ -496,3 +517,48 @@ sub notifyOn {
 1;
 
 __END__
+
+=head1 NAME
+
+NBU::Drive - Support for tape Drives
+
+=head1 SUPPORTED PLATFORMS
+
+=over 4
+
+=item * 
+
+Solaris
+
+=item * 
+
+Windows/NT
+
+=back
+
+=head1 SYNOPSIS
+
+    To come...
+
+=head1 DESCRIPTION
+
+This module provides support for ...
+
+=head1 SEE ALSO
+
+=over 4
+
+=item L<NBU::Media|NBU::Media>
+
+=back
+
+=head1 AUTHOR
+
+Winkeler, Paul pwinkeler@pbnj-solutions.com
+
+=head1 COPYRIGHT
+
+Copyright (C) 2002-2007 Paul Winkeler
+
+=cut
+
