@@ -12,7 +12,7 @@ BEGIN {
   use Exporter   ();
   use AutoLoader qw(AUTOLOAD);
   use vars       qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
-  $VERSION =	 do { my @r=(q$Revision: 1.7 $=~/\d+/g); sprintf "%d."."%02d"x$#r,@r };
+  $VERSION =	 do { my @r=(q$Revision: 1.11 $=~/\d+/g); sprintf "%d."."%02d"x$#r,@r };
   @ISA =         qw();
   @EXPORT =      qw();
   @EXPORT_OK =   qw();
@@ -27,6 +27,7 @@ sub new {
 
   if (@_) {
     $fragment->{NUMBER} = shift;
+    $fragment->{COPY} = shift;
     $fragment->{IMAGE} = shift;
     $fragment->{VOLUME} = shift;
     $fragment->{OFFSET} = shift;
@@ -45,6 +46,12 @@ sub number {
   return $self->{NUMBER};
 }
 
+sub copy {
+  my $self = shift;
+
+  return $self->{COPY};
+}
+
 #
 # Volume offset data is stored in blocks but reported back in KBytes
 sub offset {
@@ -92,3 +99,48 @@ sub image {
 1;
 
 __END__
+
+=head1 NAME
+
+NBU::Fragment - Interface to backup set fragments as stored by NetBackup
+
+=head1 SUPPORTED PLATFORMS
+
+=over 4
+
+=item * 
+
+Solaris
+
+=item * 
+
+Windows/NT
+
+=back
+
+=head1 SYNOPSIS
+
+    To come...
+
+=head1 DESCRIPTION
+
+This module provides support for ...
+
+=head1 SEE ALSO
+
+=over 4
+
+=item L<NBU::Media|NBU::Media>
+
+=back
+
+=head1 AUTHOR
+
+Winkeler, Paul pwinkeler@pbnj-solutions.com
+
+=head1 COPYRIGHT
+
+Copyright (C) 2002-2007 Paul Winkeler
+
+=cut
+
